
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class V1::ActionsController < ApplicationController
  include ::Paginator

  before_action :set_action, only: [:show, :update, :destroy]
  before_action :authenticate_user!, except: [:index, :show]
  before_action :authorize!, only: [:update, :destroy]

  # GET /v1/actions
  def index
    actions = paginate Action
    render json: actions
  end

  # GET /v1/actions/1
  def show
    render json: @action
  end

  # POST /v1/actions
  def create
    @action = Action.new(action_params)
    authorize @action

    if @action.save
      render json: @action, status: :created
    else
      render json: @action.errors, status: :unprocessable_entity
    end
  end

  # PUT/PATCH /v1/actions/1
  def update
    if @action.update(action_params)
      render json: @action, status: :ok
    else
      render json: @action.errors, status: :unprocessable_entity
    end
  end

  # DELETE /v1/actions/1
  def destroy
    @action.destroy
    response = { 'status': 'deleted' }
    render status: :ok, json: response
  end

  private

  def set_action
    @action ||= Action.find_by_id(params[:id])
    if @action.blank?
      render status: :not_found
    end
  end

  def action_params
    params.require(:action_params).permit(:name, :description, :reward_experience)
  end

  def authorize!
    authorize @action
  end

end
