# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

# == Schema Information
#
# Table name: achievements

# t.string      :name
# t.string      :description
# t.integer     :reward_experience
# t.integer     :reward_points
# t.integer     :state 
# t.integer     :repeatable
# t.boolean     :resettable
# t.datetime    :created_at
# t.datetime    :updated_at

class Achievement < ApplicationRecord
  has_many   :items
  has_many   :unlocked_achievements
  has_many   :users, through: :unlocked_achievements
  has_and_belongs_to_many :requirements

  enum state: [:inactive, :active, :deleted]
  enum repeatable: [:never, :daily, :weekly, :monthly, :yearly]

  validates_presence_of :name, :description, :reward_experience, :reward_points, :state, :repeatable

  def add_requirements(ids=[])
    errors = []
    ids.each do |requirement_id|
      if !requirement_ids.include?(requirement_id)
        requirement = Requirement.where(id: requirement_id).first
        if !requirement.blank?
          requirements << requirement
        else
          errors << {error_type:"inexistent", id: requirement_id}
        end
      else
        errors << {error_type:"repeated", id: requirement_id}
      end
    end

    return errors
  end

  def remove_requirements(ids=[])
    ids.each do |requirement_id|
      requirement = requirements.where(id: requirement_id).first
      if !requirement.blank?
        self.requirements.delete(requirement)
      end
    end
  end

  def update_requirements(ids)
    ids ||= []
    add_requirements(ids - requirement_ids)
    remove_requirements(requirement_ids - ids)
  end
end
