
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

# == Schema Information
#
# Table name: collection_items
#
#  id                  :integer          not null, primary key
#  collectionable_id   :integer
#  collectionable_type :string
#  collection_id       :integer
#  position               :integer
#  created_at          :datetime         not null
#  updated_at          :datetime         not null
#

class CollectionItem < ApplicationRecord
  # *current_user* add item *collectionable* to *collection*
  include Trackable

  after_create :create_action

  belongs_to :collection
  belongs_to :collectionable, polymorphic: true

  validates :collection, :collectionable, presence: true
  acts_as_list scope: :collection

  acts_as_paranoid

  def recipient
    collection
  end

  def public?
    collectionable.privacy == 'public'
  end

  def owner?(candidate)
    collectionable.owner == candidate
  end

  def thumbnail
    collectionable_type == 'LearningObject' ?  LearningObject.find(collectionable_id).default_thumbnail : Collection.find(collectionable_id).thumbnail
  end

  private

  def create_action
    collection.owner.complete_action(Action.find_by_name("Adicionar Recurso a Coleção")) if collectionable_type == "LearningObject"
  end
end
