
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

module Stageable
  extend ActiveSupport::Concern

  included do
    has_many :stage_relations, as: :stageable, dependent: :destroy
    has_many :educational_stages, through: :stage_relations, dependent: :destroy
  end

  # A stageable can add educational stages
  # Examples:
  # stageable.add_educational_stages(ids: [1, 2, 3])
  # stageable.add_educational_stages(ids: [1])
  def add_educational_stages(ids: [])
    ids.each do |educational_stage_id|
      educational_stage = EducationalStage.find(educational_stage_id)
      self.educational_stages << educational_stage
    end
  end

  # A stageable can remove educational stages
  # Examples:
  # stageable.remove_educational_stages(ids: [1, 2, 3])
  def remove_educational_stages(ids: [])
    ids.each do |educational_stage_id|
      educational_stage = EducationalStage.find(educational_stage_id)
      StageRelation.where(educational_stage: educational_stage, stageable: self).destroy_all
      self.educational_stages.delete(educational_stage)
    end
  end

  def update_educational_stages(ids: [])
    stageable = self
    old_ids = stageable.educational_stages.map {|es| es.id }
    add_educational_stages(ids: ids - old_ids)
    remove_educational_stages(ids: old_ids - ids)
  end
end
