
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'mimemagic'

##
# This abstract class representes the interface to generate thumbnails
module Thumbnail
  class GeneratableStrategy

    ##
    # Generate a thumbnail based on the +media+
    # +media+ needs to be a pointer to a file
    def generate(media)
      raise NotImplementedError
    end

    ##
    # Checks if the strategy can generate a thumbnail of that +media+
    def can_generate?(media)
      if File == media.class
        mime = MimeMagic.by_magic(media)
        return mime.type.include? yield unless mime.blank?
      end
      false
    end

  end
end
