
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'acceptance_helpers'
require 'shared/contexts'

resource 'Action' do
  header 'Accept', 'application/json'
  header 'Content-Type', 'application/json'

  explanation "Users can perform some pre-defined Actions in the system to collect experience."

  before { 12.times { create(:action) } }

  let(:actions) { Action.all }

  get '/v1/actions' do
    parameter :limit, 'Limit of actions'
    parameter :offset, 'Offset of actions'

    let(:limit) { 12 }
    let(:offset) { 0 }

    example_request 'Get a list of actions' do
      expect(JSON.parse(response_body).map { |o| o['id'] }.sort).to eq(Action.limit(limit).offset(offset).pluck(:id).sort)
      expect(status).to eq(200)
    end
  end

  get '/v1/actions/:id' do
    let(:id) { actions.first.id }

    example 'Get an action' do
      do_request
      expect(path).to eq("/v1/actions/#{id}") # `:id` is replaced with the value of `id`
      expect(response_body).to eq(Helper.serialize(Action.find(id)))
      expect(status).to eq(200)
    end
  end

  post '/v1/actions' do
    include_context "authenticate_user_editor"

    parameter :name, 'The name of the action', scope: :action_params
    parameter :description, 'The description of the action', scope: :action_params
    parameter :reward_experience, 'Amount of experience rewarded when the action is completed', scope: :action_params

    let(:name) { Faker::Name.name }
    let(:description) { Faker::Lorem.paragraph}
    let(:reward_experience) { rand(0..100) }
    let(:raw_post) { params.to_json }

    example 'Creating an action' do
      do_request
      expect(status).to eq(201)
    end
  end

  put '/v1/actions/:id' do
    include_context "authenticate_user_editor"

    parameter :name, 'The name of the action', scope: :action_params
    parameter :description, 'The description of the action', scope: :action_params
    parameter :reward_experience, 'Amount of experience rewarded when the action is completed', scope: :action_params

    let(:id) { @action.id }
    let(:description) { Faker::Lorem.paragraph }
    let(:raw_post) { params.to_json }

    before do
      @action = create(:action)
    end

    example 'Updating an action' do
      do_request
      expect(status).to eq(200)
    end
  end

  delete '/v1/actions/:id' do
    include_context "authenticate_user_editor"

    let(:id) { @action.id }

    before do
      @action = create(:action)
    end

    example 'Destroying an action' do
      do_request
      expect(status).to eq(200)
    end

  end

end
