
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'acceptance_helpers'
require 'shared/contexts'

resource 'Contacts' do

  explanation "Are the contact forms of the API."

  before { 12.times { create(:contact) } }

  let(:contacts) { Contact.all }

  get '/v1/contacts' do
    include_context "authenticate_user_editor"

    example_request 'Getting all contacts' do
      expect(status).to eq(200)
    end
  end

  get '/v1/contacts/:id' do
    include_context "authenticate_user_editor"

    let(:id) { contacts.first.id }

    example_request 'Getting a contact' do
      expect(status).to eq(200)
    end
  end


  post '/v1/contacts' do

    parameter :name, 'The name of the contact', scope: :contact
    parameter :email, 'The email of the contact', scope: :contact
    parameter :message, 'The message of the contact', scope: :contact

    let(:name) { Faker::Name.name }
    let(:email) { Faker::Internet.email }
    let(:message) { Faker::Lorem.sentence }
    let(:raw_post) { params.to_json }

    example_request 'Create contacts' do
      expect(status).to eq(201)
    end
  end

  put '/v1/contacts/:id' do
    include_context "authenticate_user_editor"

    parameter :name, 'The name of the contact', scope: :contact
    parameter :email, 'The email of the contact', scope: :contact
    parameter :message, 'The message of the contact', scope: :contact

    let(:id) { contacts.first.id }
    let(:name) { Faker::Name.name }
    let(:email) { Faker::Internet.email }
    let(:message) { Faker::Lorem.sentence }
    let(:raw_post) { params.to_json }

    example_request 'Updating contacts' do
      expect(status).to eq(200)
    end
  end

  delete '/v1/contacts/:id' do
    include_context "authenticate_user_editor"

    let(:id) { contacts.first.id }

    example_request 'Destroy a contact' do
      expect(status).to eq(200)
    end
  end

end
