
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'acceptance_helpers'
require 'shared/contexts'

resource 'Progress' do
    header 'Accept', 'application/json'
    header 'Content-Type', 'application/json'

    explanation " The progress for achievements in the system for each user"

    before { 12.times { create(:progress) } }

    let(:progresses) { Progress.all }

   
    get '/v1/progresses' do   #index
        include_context "authenticate_user"

        before { 12.times { create(:progress, user: @user) }}

        parameter :limit, 'Limit of progresses'
        parameter :offset, 'Offset of progresses'

        let(:limit) { 12 }
        let(:offset) { 0 }

        example_request 'Get a list of progresses from a user' do
            expect( JSON.parse(response_body).map { |o| o['id'] }.sort ).to eq( @user.progresses.limit(limit).offset(offset).pluck(:id).sort )
            expect(status).to eq(200)
        end
    end

    get '/v1/progresses/:id' do
        
        let(:id) { progresses.first.id }      

        example 'Get a specific progress' do
            do_request
            expect(path).to eq("/v1/progresses/#{id}")
            expect(response_body).to eq(Helper.serialize(Progress.find(id)))
            expect(status).to eq(200)
        end
    end
end